Enum cargo_actions::ActionsArgs
source · pub enum ActionsArgs {
Init(InitArgs),
Login,
Upload(UploadArgs),
Mine,
Favorite,
}Expand description
Represents different actions that can be performed by the application.
Variants
Init(InitArgs)
Initializes a new GitHub Actions workflow in your project.
Login
Authenticates the user with GitHub.
Upload(UploadArgs)
Uploads a custom template to Cargo Actions for future use.
Mine
Initializes a GitHub Actions workflow based on a template saved by the user.
Favorite
Initializes a GitHub Actions workflow using a template from the user’s favorites.